@@ -18,13 +18,13 @@ grid.newpage()
 gf <- grid.frame(draw=TRUE)
 grid.pack(gf, grid.rect(x=unit(1, "npc"), 
                         w=unit(1, "char"), h=unit(1, "char"),
-                        just=c("right", "centre"), draw=F))
-grid.pack(gf, grid.text("A label", draw=F), side="right")
+                        just=c("right", "centre"), draw=FALSE))
+grid.pack(gf, grid.text("A label", draw=FALSE), side="right")
 
 grid.newpage()
 gf <- grid.frame(draw=TRUE)
 grid.pack(gf, grid.rect(width=unit(1, "inches"),
                         height=unit(.5, "npc"),
-                        draw=F))
+                        draw=FALSE))
 
 dev.off()
